@@ -30,7 +30,9 @@ extern SEXP _transport_cgal_present();
 extern SEXP _transport_semidiscrete_p1(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _transport_cplex_present();
 extern SEXP _transport_SolveHierarchicalTransport(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-
+extern SEXP _transport_networkflow(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _transport_gen_cost(SEXP, SEXP, SEXP);
+extern SEXP _transport_openmp_present();
 
 static const R_CMethodDef CEntries[] = {
     {"aha_compute_transport", (DL_FUNC) &aha_compute_transport,  6},
@@ -53,10 +55,13 @@ static const R_CMethodDef CEntries[] = {
 
 static const R_CallMethodDef CallEntries[] = {
     {"_transport_create_diagram", (DL_FUNC) &_transport_create_diagram, 1},
-    {"_transport_cgal_present", (DL_FUNC) &_transport_cgal_present, 0},
+    {"_transport_cgal_present", (DL_FUNC) &_transport_cgal_present,0},
     {"_transport_semidiscrete_p1", (DL_FUNC) &_transport_semidiscrete_p1, 6},
     {"_transport_cplex_present", (DL_FUNC) &_transport_cplex_present, 0},
     {"_transport_SolveHierarchicalTransport", (DL_FUNC) &_transport_SolveHierarchicalTransport, 13},
+    {"_transport_networkflow", (DL_FUNC) &_transport_networkflow, 4},
+    {"_transport_gen_cost", (DL_FUNC) &_transport_gen_cost, 3},
+    {"_transport_openmp_present", (DL_FUNC) &_transport_openmp_present, 0},
     {NULL, NULL, 0}
 };
 
